import React from "react";
import { string, object, arrayOf, oneOfType, node } from "prop-types";
import { STATUS } from "./iocStatusData";
import { Stack } from "@mui/material";
import WarningAmberIcon from "@mui/icons-material/WarningAmber";
import ErrorOutlineIcon from "@mui/icons-material/ErrorOutline";

const propTypes = {
  status: string,
  theme: object,
  children: oneOfType([arrayOf(node), node])
};

const commonStyles = {
  position: "absolute",
  top: "-10px",
  left: "14px",
  fontSize: "20px"
};

export const IOCStatusBadge = ({ status, theme, children }) => (
  <Stack sx={{ position: "relative" }}>
    {children}
    {status === STATUS.warning ? (
      <WarningAmberIcon
        sx={{ fill: theme.palette.warning.main, ...commonStyles }}
      />
    ) : (
      <>
        {status === STATUS.alert || status === STATUS.inactiveAlert ? (
          <ErrorOutlineIcon
            sx={{ fill: theme.palette.error.main, ...commonStyles }}
          />
        ) : null}
      </>
    )}
  </Stack>
);

IOCStatusBadge.propTypes = propTypes;
