import {
  Brightness1,
  StopCircle,
  RadioButtonUnchecked,
  HelpOutline
} from "@mui/icons-material";

export const STATUS = {
  active: "active",
  disabled: "disabled",
  alert: "alert",
  warning: "warning",
  inactive: "inactive",
  inactiveAlert: "inactive alert"
};

export const SEVERITY = {
  info: "info",
  alert: "error",
  warning: "warning"
};

export const statusConfig = {
  [STATUS.active]: {
    title: "Active",
    icon: Brightness1
  },
  [STATUS.disabled]: {
    title: "Disabled",
    icon: StopCircle
  },
  [STATUS.alert]: {
    title: "Alert",
    icon: Brightness1
  },
  [STATUS.warning]: {
    title: "Warning",
    icon: Brightness1
  },
  [STATUS.inactive]: {
    title: "Inactive",
    icon: RadioButtonUnchecked
  },
  [STATUS.inactiveAlert]: {
    title: "Alert",
    icon: RadioButtonUnchecked
  },
  null: {
    title: "Unknown",
    icon: HelpOutline
  }
};

export const getIocStatus = (ioc) => {
  let { active, activeDeployment } = ioc;
  const alertSeverity = ioc?.alertSeverity?.toLowerCase();

  if (
    active &&
    (alertSeverity === undefined || alertSeverity === SEVERITY.info)
  ) {
    // Active status / running
    return STATUS.active;
  } else if (
    active === false &&
    (alertSeverity === undefined || alertSeverity === SEVERITY.info)
  ) {
    // stopped/paused
    return STATUS.disabled;
  } else if (
    active !== undefined &&
    alertSeverity !== undefined &&
    alertSeverity === SEVERITY.alert
  ) {
    // error
    return STATUS.alert;
  } else if (
    active !== undefined &&
    alertSeverity !== undefined &&
    alertSeverity === SEVERITY.warning
  ) {
    // warning
    return STATUS.warning;
  } else if (
    (!active || activeDeployment === null) &&
    (alertSeverity === undefined || alertSeverity === SEVERITY.info)
  ) {
    // Inactive status
    return STATUS.inactive;
  } else if (
    (!active || activeDeployment === null) &&
    alertSeverity !== undefined &&
    alertSeverity !== SEVERITY.info
  ) {
    // inactive with warning/error
    return STATUS.inactiveAlert;
  } else {
    // unknown fallback state
    return null;
  }
};
