import React, { useCallback } from "react";
import { Typography } from "@mui/material";
import {
  SimpleAccordion,
  InternalLink,
  EmptyValue
} from "@ess-ics/ce-ui-common";
import { IOCDetails } from "../IOCDetails";
import { LokiContainer } from "../../common/Loki/LokiContainer";
import { RecordSearch } from "../../records/RecordSearch";
import GitRefLink from "../GitRefLink";
import { AlertBannerList } from "@ess-ics/ce-ui-common";
import AccessControl from "../../auth/AccessControl";
import { IocActiveDeployment } from "../../../api/DataTypes";
import useUrlState from "@ahooksjs/use-url-state";
import { serialize, deserialize } from "../../common/URLState/URLState";

export function IOCLiveStatus({ ioc }) {
  const [state, setState] = useUrlState(
    {
      procserv_log_open: "true",
      records_open: "false"
    },
    { navigateMode: "replace" }
  );

  const liveIOC = { ...ioc };
  liveIOC.name = ioc.namingName;

  const getSubset = useCallback((ioc) => {
    const iocHasDeployment = new IocActiveDeployment(
      ioc.activeDeployment
    ).hasDeployment();

    let subset = {
      Description: ioc.description,
      Revision: iocHasDeployment ? (
        <GitRefLink
          url={ioc.activeDeployment?.sourceUrl}
          displayReference={ioc.activeDeployment?.sourceVersion}
          revision={ioc.activeDeployment?.sourceVersion}
        />
      ) : (
        <EmptyValue />
      ),
      "Deployed on":
        iocHasDeployment && ioc.activeDeployment?.host.externalIdValid ? (
          <Typography>
            {ioc.activeDeployment?.host.hostId ? (
              <InternalLink
                to={`/hosts/${ioc.activeDeployment?.host.hostId}`}
                label={`Host details, ${ioc.activeDeployment?.host.fqdn}`}
              >
                {ioc.activeDeployment?.host.fqdn}
              </InternalLink>
            ) : (
              ioc.activeDeployment?.host.fqdn
            )}
          </Typography>
        ) : (
          <EmptyValue />
        )
    };

    return subset;
  }, []);

  function isIocDeployed(ioc) {
    return Boolean(ioc.activeDeployment);
  }

  return (
    <>
      <IOCDetails
        ioc={liveIOC}
        getSubset={getSubset}
        alert={<AlertBannerList alerts={liveIOC.alerts} />}
      />
      {liveIOC.activeDeployment?.host?.externalIdValid && (
        <AccessControl
          allowedRoles={["DeploymentToolAdmin", "DeploymentToolIntegrator"]}
          renderNoAccess={() => <></>}
        >
          <LokiContainer
            hostName={liveIOC.activeDeployment?.host.hostName}
            iocName={ioc.namingName}
            isDeployed={isIocDeployed(ioc)}
          />
          <SimpleAccordion
            summary="Records"
            expanded={deserialize(state.records_open)}
            onChange={(event, expanded) =>
              setState({ records_open: serialize(expanded) })
            }
          >
            <RecordSearch
              iocName={ioc.namingName}
              rowType="iocDetails"
            />
          </SimpleAccordion>
        </AccessControl>
      )}
    </>
  );
}
