import { Stepper, STEPPER_STATES, LabeledIcon } from "@ess-ics/ce-ui-common";
import { HelpOutline } from "@mui/icons-material";
import React from "react";

const ActiveIcon = STEPPER_STATES.active.outlinedIcon;
const CompletedIcon = STEPPER_STATES.completed.outlinedIcon;
const ErrorIcon = STEPPER_STATES.error.outlinedIcon;

const STEPPER_STATUS = {
  queued: {
    label: "Queued",
    alertType: "info",
    icon: ActiveIcon,
    color: STEPPER_STATES.active.color.main
  },
  running: {
    label: "Running",
    alertType: "info",
    icon: ActiveIcon,
    color: STEPPER_STATES.active.color.main
  },
  successful: {
    label: "Completed",
    alertType: "success",
    icon: CompletedIcon,
    color: STEPPER_STATES.completed.color.main
  }
};

const STATUS = {
  ...STEPPER_STATUS,
  failed: {
    label: "Error",
    alertType: "error",
    icon: ErrorIcon,
    color: STEPPER_STATES.error.color.main
  },
  unknown: {
    label: "Unknown",
    alertType: "info",
    icon: HelpOutline,
    color: STEPPER_STATES.disabled.color.main
  }
};

export const JobStatusStepper = ({ job, operation }) => {
  const normalizedStatus = job?.status?.toLowerCase();
  const currentStep = Object.keys(STEPPER_STATUS).indexOf(normalizedStatus);
  let activeStep = STEPPER_STATUS[normalizedStatus]
    ? currentStep + 1
    : currentStep;
  const jobFailed = job?.status?.toLowerCase() === "failed";

  // to show the correct failed step for an already finished operation
  if (jobFailed) {
    activeStep = operation?.startTime ? 1 : 0;
  }

  return (
    <Stepper
      steps={Object.values(STEPPER_STATUS).map((it) => it.label)}
      activeStep={activeStep}
      isActiveStepFailed={jobFailed}
    />
  );
};

export const JobStatusIcon = ({ job }) => {
  const activeStep = STATUS[job?.status?.toLowerCase()] ?? STATUS.unknown;

  return (
    <LabeledIcon
      label={activeStep.label}
      labelPosition="right"
      LabelProps={{
        color:
          activeStep.alertType === "error" ? STATUS.failed.color : "inherit"
      }}
      Icon={activeStep.icon}
      IconProps={{
        style: {
          fill: activeStep.color
        }
      }}
    />
  );
};
