import React, { useState, useEffect } from "react";
import { Table } from "@ess-ics/ce-ui-common";
import { JobStatusColumn } from "./JobStatusColumn";
import { JobSummaryColumn } from "./JobSummaryColumn";
import { UserAvatar } from "../../common/User/UserAvatar";
import { JobHostColumn } from "./JobHostColumn";

const defaultColumns = [
  {
    field: "status",
    headerName: "Status"
  },
  {
    field: "job",
    headerName: "Job",
    width: "100%"
  },
  {
    field: "host",
    headerName: "Host"
  },
  {
    field: "user",
    headerName: "User",
    align: "center",
    headerAlign: "center"
  }
];

const shapeColumns = (customColumns) => {
  return customColumns.map((column) => {
    const mappedCol = defaultColumns.find((col) => col.field === column.field);
    return mappedCol ? { ...mappedCol, ...column } : null;
  });
};

const createTableRow = (job, colorStyle) => ({
  id: job.id,
  status: <JobStatusColumn {...{ job }} />,
  job: <JobSummaryColumn {...{ job, colorStyle }} />,
  host: <JobHostColumn {...{ job }} />,
  user: <UserAvatar username={job.createdBy} />
});

export const JobTable = ({
  jobs,
  customColumns,
  pagination,
  onPage,
  loading
}) => {
  const [columns, setColumns] = useState(null);

  useEffect(() => {
    if (customColumns) {
      setColumns(shapeColumns(customColumns));
    } else {
      setColumns(defaultColumns);
    }
  }, [customColumns, setColumns]);

  return (
    <>
      {columns ? (
        <Table
          columns={columns}
          rows={columns && jobs?.map((job) => createTableRow(job))}
          pagination={pagination}
          onPage={onPage}
          loading={loading}
          rowHeight={90}
        />
      ) : null}
    </>
  );
};
