import { useContext, useCallback } from "react";
import { apiContext } from "../../../api/DeployApi";
import { userContext, useAPIMethod, usePolling } from "@ess-ics/ce-ui-common";

export default function TokenRenew() {
  const { user } = useContext(userContext);

  const client = useContext(apiContext);
  const {
    wrapper: renewToken,
    loading,
    abort
  } = useAPIMethod({
    fcn: client.apis.Authentication.tokenRenew,
    call: false
  });

  const renewTokenWhenLoggedIn = useCallback(() => {
    if (user) {
      renewToken();

      return () => {
        abort();
      };
    }
  }, [user, renewToken, abort]);

  usePolling(
    renewTokenWhenLoggedIn,
    loading,
    window.TOKEN_RENEW_INTERVAL,
    abort
  );

  return null;
}
