import React, { useCallback, useContext } from "react";
import { Card, CardHeader } from "@mui/material";
import { initRequestParams } from "../Helper";
import { useEffect } from "react";
import { JobTable } from "../../Job";
import { apiContext } from "../../../api/DeployApi";
import { useAPIMethod, usePagination, usePolling } from "@ess-ics/ce-ui-common";

export function UserOperationList({ userName }) {
  const client = useContext(apiContext);

  const {
    value: operations,
    wrapper: getOperations,
    loading,
    dataReady,
    abort
  } = useAPIMethod({
    fcn: client.apis.Deployments.listOperations,
    call: false
  });

  const rowsPerPage = [20, 50];
  const { pagination, setPagination } = usePagination({
    rowsPerPageOptions: rowsPerPage,
    initLimit: rowsPerPage[0],
    initPage: 0
  });

  // update pagination whenever search result total pages change
  useEffect(() => {
    setPagination({ totalCount: operations?.totalCount ?? 0 });
  }, [setPagination, operations?.totalCount]);

  const callGetOperations = useCallback(() => {
    let requestParams = initRequestParams(pagination);

    requestParams.user = userName;

    getOperations(requestParams);
  }, [getOperations, pagination, userName]);

  useEffect(() => {
    callGetOperations();

    return () => {
      abort();
    };
  }, [callGetOperations, abort]);

  usePolling(callGetOperations, loading, 30000, abort);

  // Invoked by Table on change to pagination
  const onPage = (params) => {
    setPagination(params);
    abort();
  };

  return (
    <Card variant="plain">
      <CardHeader
        title={"Operations"}
        titleTypographyProps={{
          variant: "h2",
          component: "h2"
        }}
      />
      <JobTable
        jobs={operations?.operations}
        customColumns={[
          { field: "status" },
          { field: "job" },
          { field: "host" }
        ]}
        loading={loading || !dataReady}
        pagination={pagination}
        onPage={onPage}
        rowType="userPageJobLog"
      />
    </Card>
  );
}
