import React, { useContext, useMemo } from "react";
import { Grid, Skeleton } from "@mui/material";
import { apiContext } from "../../api/DeployApi";
import { useAPIMethod } from "@ess-ics/ce-ui-common";
import { HostStatusIcon } from "./HostStatusIcon";

function createRequest(hostId) {
  return {
    host_id: hostId
  };
}

export const HostStatus = ({ hostId }) => {
  const client = useContext(apiContext);

  const params = useMemo(() => createRequest(hostId), [hostId]);

  const {
    value: hostStatus,
    loading,
    dataReady
  } = useAPIMethod({
    fcn: client.apis.Hosts.findHostStatus,
    params
  });

  return (
    <Grid
      container
      direction="column"
      justifyContent="center"
      alignItems="center"
    >
      {loading || !dataReady ? (
        <Skeleton
          variant="circular"
          height={20}
          width={20}
        />
      ) : (
        <HostStatusIcon hostStatus={hostStatus} />
      )}
    </Grid>
  );
};
