import React from "react";
import { Table, InternalLink, EllipsisText } from "@ess-ics/ce-ui-common";
import { HostStatus } from "./HostStatus";

const columns = [
  {
    field: "status",
    headerName: "Status",
    flex: 0,
    headerAlign: "center",
    align: "center"
  },
  { field: "hostName", headerName: "Host" },
  { field: "description", headerName: "Description" },
  { field: "network", headerName: "Network" },
  { field: "scope", headerName: "Network scope" }
];

export function createRow(host) {
  return {
    id: host.hostId,
    status: <HostStatus hostId={host.hostId} />,
    hostName: (
      <InternalLink
        to={`/hosts/${host.hostId}`}
        label={`Host details, ${host.name}`}
        width="100%"
      >
        <EllipsisText>{host.name}</EllipsisText>
      </InternalLink>
    ),
    host: host,
    description: <EllipsisText>{host.description}</EllipsisText>,
    network: <EllipsisText>{host.network}</EllipsisText>,
    scope: <EllipsisText>{host.scope}</EllipsisText>
  };
}

export function HostTable({ hosts, pagination, onPage, loading }) {
  return (
    <Table
      columns={columns}
      rows={hosts?.map((host) => createRow(host))}
      pagination={pagination}
      onPage={onPage}
      loading={loading}
      disableHover
    />
  );
}
