import React, { useContext, useMemo } from "react";
import { Grid, Skeleton, Typography } from "@mui/material";
import { apiContext } from "../../api/DeployApi";
import {
  useAPIMethod,
  InternalLink,
  EllipsisText,
  EmptyValue
} from "@ess-ics/ce-ui-common";

function createRequest(fqdn) {
  return {
    fqdn: fqdn
  };
}

function shortenFqdn(fqdn) {
  return fqdn.split(".")[0];
}

function createHostLink(fqdn, hostInfo) {
  // if the fqdn field is empty for some reason
  if (fqdn === null || fqdn.trim() === "") {
    return <EmptyValue />;
  }

  // create host link only if the host exists in CSEntry
  if (hostInfo) {
    return (
      <InternalLink
        to={`/hosts/${hostInfo.hostId}`}
        label={`Record host details, ${fqdn}}`}
        width="100%"
      >
        <EllipsisText>{shortenFqdn(fqdn)}</EllipsisText>
      </InternalLink>
    );
  }

  return <Typography>{fqdn}</Typography>;
}

export const RecordHostLink = ({ fqdn }) => {
  const client = useContext(apiContext);

  const params = useMemo(() => createRequest(fqdn), [fqdn]);

  const {
    value: hostInfo,
    loading,
    dataReady
  } = useAPIMethod({
    fcn: client.apis.Hosts.findNetBoxHostByFqdn,
    params
  });

  return (
    <Grid
      container
      direction="column"
      justifyContent="center"
      alignItems="center"
    >
      {loading || !dataReady ? (
        <Skeleton width="100%" />
      ) : (
        createHostLink(fqdn, hostInfo)
      )}
    </Grid>
  );
};
