import React from "react";
import { Container } from "@mui/material";
import hosts from "../../../../mocks/fixtures/Hosts.json";
import { rest } from "msw";
import { HostTable } from "../../../../components/host/HostTable";
import { RouterHarness } from "../../../../mocks/AppHarness";
import {
  hideStorybookControls,
  paginationNoResults
} from "../../../utils/common-args";

export default {
  title: "Host/HostTable",
  argTypes: {
    hosts: hideStorybookControls,
    totalCount: hideStorybookControls,
    rowsPerPage: hideStorybookControls,
    lazyParams: hideStorybookControls,
    columnSort: hideStorybookControls,
    setLazyParams: hideStorybookControls,
    setColumnSort: hideStorybookControls
  }
};

const Template = (args) => (
  <RouterHarness>
    <Container>
      <HostTable {...args} />
    </Container>
  </RouterHarness>
);

export const Empty = (args) => <Template {...args} />;

Empty.args = {
  loading: false,
  hosts: [],
  totalCount: 0,
  rowsPerPage: [5, 10, 20, 50, 100],
  lazyParams: { rows: 10, page: 0 },
  columnSort: { sortField: null, sortOrder: null },
  setLazyParams: () => {},
  setColumnSort: () => {}
};

export const EmptyLoading = (args) => <Template {...args} />;

EmptyLoading.args = {
  ...Empty.args,
  loading: true
};

export const BeforeAsync = (args) => <Template {...args} />;

BeforeAsync.args = {
  ...Empty.args,
  pagination: { ...paginationNoResults, totalCount: hosts.totalCount },
  hosts: hosts.netBoxHosts
};
BeforeAsync.argTypes = {
  loading: hideStorybookControls
};
BeforeAsync.parameters = {
  msw: {
    handlers: [
      rest.get("*/hosts/*", (req, res, ctx) => res(ctx.delay("infinite"))),
      rest.get("*/hosts/:host_id/status", (req, res, ctx) => {
        const { host_id } = req.params; // eslint-disable-line
        res(ctx.delay("infinite"));
      })
    ]
  }
};

export const AfterAsync = (args) => <Template {...args} />;
AfterAsync.args = { ...BeforeAsync.args };
AfterAsync.argTypes = { ...BeforeAsync.argTypes };
