import React, { useEffect, useContext, useCallback } from "react";
import IOCTable from "../../../components/IOC/IOCTable";
import { string, number, func } from "prop-types";
import { apiContext } from "../../../api/DeployApi";
import { Typography } from "@mui/material";
import { useAPIMethod, usePagination } from "@ess-ics/ce-ui-common";
import { initRequestParams } from "../../../components/common/Helper";
import { serialize } from "../../../components/common/URLState/URLState";

const propTypes = {
  hostId: string,
  row: number,
  page: number,
  onUrlStateChange: func
};

export const HostIocSection = ({ hostId, rows, page, onUrlStateChange }) => {
  const client = useContext(apiContext);
  const { pagination, setPagination, setTotalCount } = usePagination({
    initLimit: rows,
    initPage: page
  });

  const {
    value: iocs,
    wrapper: callgetIocs,
    loading,
    dataReady,
    abort: abortGetIocs
  } = useAPIMethod({
    fcn: client.apis.Hosts.findAssociatedIocsByHostId,
    call: false
  });

  const onPage = useCallback(
    (params) => {
      setPagination(params);
      abortGetIocs();
      onUrlStateChange({
        iocs_rows: serialize(params.limit),
        iocs_page: serialize(params.page)
      });
    },
    [setPagination, abortGetIocs, onUrlStateChange]
  );

  const getIocs = useCallback(() => {
    let requestParams = initRequestParams({ page, rows }, null);
    requestParams.host_id = hostId;
    callgetIocs(requestParams);
  }, [callgetIocs, hostId, page, rows]);

  // update pagination whenever search result total pages change
  useEffect(() => {
    setTotalCount(iocs?.totalCount ?? 0);
  }, [setTotalCount, iocs?.totalCount]);

  useEffect(() => {
    getIocs();

    return () => {
      abortGetIocs();
    };
  }, [rows, page, abortGetIocs, getIocs]);

  return (
    <>
      <Typography
        variant="h3"
        component="h2"
      >
        IOCs
      </Typography>
      <IOCTable
        iocs={iocs?.deployedIocs}
        loading={loading || !dataReady}
        rowType="host"
        pagination={pagination}
        onPage={onPage}
      />
    </>
  );
};

HostIocSection.propTypes = propTypes;
